@@ -7,7 +7,7 @@ import packaging.version
 from core_changelog_md.common.enums import ChangeTypes
 from core_changelog_md.common.exceptions import UnCorrectTitleException, \
     MissedVersionsSymbolException, VersionOverTextException, NotDetectVersionException, VersionDateConvertException, \
-    UnDetectLine, MissChangeBlock
+    UnDetectLine, MissChangeBlock, UnKnownVersionAppendText
 from core_changelog_md.exceptions import VersionNotFoundException
 from core_changelog_md.objects.changes import ChangeCollection, ChangeBlock
 from core_changelog_md.objects.version import VersionCollection, VersionBlock
@@ -50,34 +50,34 @@ class Changelog(object):
             raise VersionDateConvertException()
 
     @staticmethod
-    def check_version_name(version_name: str) -> str:
+    def check_version_name(version_name: str) -> (str, bool):
         """
         Возвращает имя версии
         """
+        is_prerelease = False
         _version_name = version_name.replace(" ", "")
         if not _version_name.startswith("##") or \
                 _version_name.startswith("##") and _version_name.startswith("###") or \
-                "[" not in _version_name and "]" not in _version_name:
-            raise MissedVersionsSymbolException()
-
-        if not _version_name.startswith('##['):
+                "[" not in _version_name or "]" not in _version_name:
             raise MissedVersionsSymbolException(
                 f'Version title must be "## [x.x.x]" or "## [version_name]"\nActual" {_version_name}')
+
+        if not _version_name.replace(" ", '').startswith('##['):
+            raise MissedVersionsSymbolException(
+                f'Version title must be "## [x.x.x]" or "## [version_name]"\nActual" {_version_name}')
+
         if '[unreleased]' in _version_name.lower():
             version = 'unreleased'
         else:
             versions = VersionBlock.RE_NUM_VERSION_BLOCK.findall(_version_name)
             version = versions[0] if len(versions) == 1 else None
         if not version:
-            versions = VersionBlock.RE_NUM_VERSION_BLOCK.findall(_version_name)
-            version = versions[0] if len(versions) == 1 else None
-        if not version:
+            is_prerelease = True
             versions = VersionBlock.RE_NUM_RC_VERSION_BLOCK.findall(_version_name)
-            split = versions[0].split('.') if len(versions) == 1 else None
-            if split:
-                version = ".".join(split[:-1]) + split[-1]
+            version = versions[0] if len(versions) == 1 else None
+            version = version.replace('.rc', 'rc')
         if version:
-            return version
+            return version, is_prerelease
         raise NotDetectVersionException(f"Cant detect version name from '{_version_name}'")
 
     @staticmethod
@@ -114,12 +114,17 @@ class Changelog(object):
                 continue
             # Старт обработки новой версии
             elif item.strip().startswith("##") and not item.strip().startswith("###"):
-                version_name = Changelog.check_version_name(version_name=item)
-                obj.versions.append(VersionBlock(
+                version_name, is_prerelease = Changelog.check_version_name(version_name=item)
+                version_obj = VersionBlock(
                     version=version_name,
                     date=Changelog.check_version_date(version_name=item),
                     change_collection=ChangeCollection()
-                ))
+                )
+                if is_prerelease:
+                    if not version_obj.version.is_prerelease:
+                        name = version_obj.version.base_version
+                        raise UnKnownVersionAppendText(f'Find unknown text in version "{name}" Only "rc" supported!')
+                obj.versions.append(version_obj)
                 change_tag = None
                 continue
             # Старт обработки нового change-tag
@@ -147,9 +152,8 @@ class Changelog(object):
         """
         Возвращает текущую версию Changelog
         """
-        if len(self.versions) > 1:
-            return max(list(self.versions)[1:]) if self.unreleased else max(list(self.versions))
-        return self.unreleased
+        version_list = [item for item in list(self.versions)[1:] if not item.version.is_prerelease]
+        return self.unreleased if len(version_list) == 0 else max(version_list)
 
     @property
     def next_version(self) -> str:
